<html>
<head>
  <link rel="stylesheet" href="http://pall.sigurdsson.is/css/style.css" />
</head>
<body>

    <div id="main">
        <div id="box" >
            <div class="main_body"><div class="content"><div class=wrapper><div class="main_content">
                <h1>List of Nodes</h1>
                <table class=table border=1 style="width: 100%; border-collapse:collapse; border: 0.5px solid grey;">
                    <thead>
                        <tr>
                            <th>Node Name</th>
                            <th>Address</th>
                            <th>Access</th>
                            <th>Last Connect</th>
                            <th>Data</th>
                        </tr>
                    </thead>
                    <tbody>
                    {% for node in nodes %}

                    <tr>
                        <td><a href="{{ url_for("node_detail", node_name=node.host_name )}}">{{ node.host_name }}</a></td>
                        <td>{{ node.address }}</td>
                        <td>{{ node.access }} </td>
                        <td>{{ node.get_info("last_connect") or "" }}</td>
                        <td>
                            {% for i in node.get_info().keys() %}
                                <a href="{{ url_for("call_method", extension_name="info", method_name="get") }}?security_token={{node.token}}&key={{i}}">{{ i }}</a>,
                            {% endfor %}
                        </td>
                    </tr>
                    {% endfor %}
                    </tbody>
                </table>
            </div></div></div></div>
        </div>
</body>
</html>
